@@ -2077,17 +2077,17 @@ def override(context, team_name, engineer, hours, start_date, end_date):  # pyli
         start_dt = pendulum.now(tz='Europe/Amsterdam')
         end_dt = start_dt.add(hours=hours)
     elif start_date and end_date:
-        start_dt = pendulum.parse(start_date, tz='Europe/Amsterdam').in_tz('UTC').format('YYYY-MM-DDTHH:mm:ss\Z')
-        end_dt = pendulum.parse(end_date, tz='Europe/Amsterdam').in_tz('UTC').format('YYYY-MM-DDTHH:mm:ss\Z')
-        result = context.obj['opsgenie'].set_override_scheduled(team_name, start_dt, end_dt, engineer)
+        start_dt = pendulum.parse(start_date, tz='Europe/Amsterdam').in_tz('UTC')
+        end_dt = pendulum.parse(end_date, tz='Europe/Amsterdam').in_tz('UTC')
+        result = context.obj['opsgenie'].set_override_scheduled(team_name, start_dt.format('YYYY-MM-DDTHH:mm:ss\Z'), end_dt.format('YYYY-MM-DDTHH:mm:ss\Z'), engineer)
     else:
         raise click.UsageError(
             "Specify the amount of hours you want to override the schedule (using --hours), \
             or specify a schedule (using --start_date and --end_date)."
         )
     if result.status_code == 201:
-        start = pendulum.parse(start_date, tz='Europe/Amsterdam').to_datetime_string()
-        end = pendulum.parse(end_date, tz='Europe/Amsterdam').to_datetime_string()
+        start = start_dt.to_datetime_string()
+        end = end_dt.to_datetime_string()
         print(f"✓ - override set to {engineer} between {start} and {end}")
     else:
         print(result.text)
